## The Biogeography of Warming Tolerance in lizards - Anderson et al. ##

# Script for biophysical modelling using the 
# NicheMapR package (Kearney & Porter, 2019. Ecography)

# Body temperatures of lizards are predicted using the 
# ectotherm function, which is parametrise with thermal physiological
# and natural history data

#packages
library(NicheMapR)
library(dplyr)

#load data - Table S1 of Supplementary Material 

data <- read.csv("Table_S1.csv", header = T)

#set dates (40 years)

dstart <- "01/01/1980"
dfinish <- "31/12/2019"

#loop through all the species in the dataset

for(i in 1:nrow(data)){
  
  
  #microclimmatic modelling
  micro <- micro_ncep(loc = c(data$Long[i], data$Lat[i]),
                      dstart = dstart, dfinish = dfinish,
                      DEP = c(0, 2.5,  5,  10,  15,  20,  30,  50,  100,  200),
                      Usrhyt = data$height[i],
                      minshade = 0, maxshade = 90,
                      runshade = 1, 
                      ERR = ERR,
                      spatial = "C:/NCEP/"
                      )
  
  #biophysical modelling
  ecto <- ectotherm(Ww_g = data$mass[i], 
                    T_RB_min = data$T_B_min[i],  # min Tb at which they will attempt to leave retreat
                    T_B_min = data$T_B_min[i],   # min Tb at which leaves retreat to bask
                    T_F_min = data$T_F_min[i],   # minimum Tb at which activity occurs
                    T_F_max = data$T_F_max[i],   # maximum Tb at which activity occurs
                    T_pref = data$Tpref[i],      # preferred Tb (will try and regulate to this)
                    CT_max = data$CTmax[i],      # critical thermal minimum (affects choice of retreat)
                    mindepth = 2,                # min depth (node, 1-10) allowed
                    maxdepth = 10,               # max depth (node, 1-10) allowed
                    shade_seek = 1,              # shade seeking?
                    burrow = data$burrow[i],     # can it burrow?
                    climb = data$climb[i],       # can it climb to thermoregulate?
                    nocturn = data$nocturn[i],   # nocturnal activity
                    crepus = data$nocturn[i],    # crepuscular activity
                    diurn = data$diurn[i],       # min available shade?
                    maxshades = micro$maxshade,
                    minshades = micro$minshade
                    ) 
  
  
  #ectotherm model output
  environ <- as.data.frame(ecto$environ)
  environ$WT <- data$CTmax[i] - environ$TC
  
  # Frames to store data
  
  output <- data.frame(Species = character(40), YEAR = numeric(40), ACT = numeric(40),
                       TC = numeric(40), TC.sd = numeric(40), BASK = numeric(40),
                       SHADE = numeric(40), SHADE.sd = numeric(40), SHADE.TIME = numeric(40),
                       WT.mean= numeric(40), WT.sd = numeric(40),
                       DEP = numeric(40), DEP.sd = numeric(40), 
                       WT.ACT = numeric(40), WT.ACT.sd = numeric (40))
  
  output.act <- data.frame(Species = character(40), YEAR = numeric(40),
                       TC = numeric(40), TC.sd = numeric(40),
                       SHADE = numeric(40), SHADE.sd = numeric(40), SHADE.TIME = numeric(40),
                       WT.mean= numeric(40), WT.sd = numeric(40),
                       DEP = numeric(40), DEP.sd = numeric(40))
  
  ## Data ##
  
  #during ACT
  
  WT.ACT <- environ %>%
            group_by(YEAR) %>%
            summarize(Mean = mean(WT[ACT ==2]),
              SD = sd(WT[ACT ==2]))
  
  as.data.frame(WT.ACT)
  output.act$WT.mean <- WT.ACT$Mean
  output.act$WT.sd <- WT.ACT$SD
  
  output.act$YEAR <- WT.ACT$YEAR
  
  #body temperature
  
  TC.act <- environ %>% 
    group_by(YEAR) %>% 
    summarize(Mean = mean(TC[ACT ==2]),
              SD = sd(TC[ACT ==2]))
  
  as.data.frame(TC.act)
  output.act$TC <- TC.act$Mean
  output.act$TC.sd <- TC.act$SD
  
  #shade time
  
  shade.time.act <- environ %>% 
    group_by(YEAR) %>% 
    tally(SHADE == 90)
  
  shade.time.act <- as.data.frame(shade.time.act)
  output.act$SHADE.TIME <- shade.time.act$n
  
  #shade use
  SHADE.act <- environ %>% 
    group_by(YEAR) %>% 
    summarize(Mean = mean(SHADE[ACT ==2]),
              SD = sd(SHADE[ACT ==2]))
  
  as.data.frame(SHADE.act)
  output.act$SHADE <- SHADE.act$Mean
  output.act$SHADE.sd <- SHADE.act$SD
  
  #depth
  depth.act <- environ %>%
    group_by(YEAR) %>%
    summarize(Mean = mean(DEP[ACT ==2]),
              SD = sd(DEP[ACT ==2]))
  
  as.data.frame(depth.act)
  output.act$DEP <- depth.act$Mean
  output.act$DEP.sd <- depth.act$SD
  
  ### global  ###
  
  #body temperature
  TC <- environ %>% 
    group_by(YEAR) %>% 
    summarize(Mean = mean(TC),
              SD = sd(TC))
  
  as.data.frame(TC)
  output$TC <- TC$Mean
  output$TC.sd <- TC$SD
  
  #activity time
  ACT <- environ %>% 
    group_by(YEAR) %>% 
    tally(ACT == 2)
  
  as.data.frame(ACT)
  output$ACT <- ACT$n
  output$YEAR <- ACT$YEAR
  
  #activity time
  BASK <- environ %>% 
    group_by(YEAR) %>% 
    tally(ACT == 1)
  
  as.data.frame(BASK)
  output$BASK <- BASK$n
  
  #shade time
  
  shade.time <- environ %>% 
    group_by(YEAR) %>% 
    tally(SHADE == 90)
  
  shade.time <- as.data.frame(shade.time)
  output$SHADE.TIME <- shade.time$n
  
  #shade use
  SHADE <- environ %>% 
    group_by(YEAR) %>% 
    summarize(Mean = mean(SHADE),
              SD = sd(SHADE))
  
  as.data.frame(SHADE)
  output$SHADE <- SHADE$Mean
  output$SHADE.sd <- SHADE$SD
  
  #warming tolerance
  warm <- environ %>%
          group_by(YEAR) %>%
          summarize(Mean = mean(WT),
                    SD = sd(WT))
  
  as.data.frame(warm)
  output$WT.mean <- warm$Mean
  output$WT.sd <- warm$SD
  
  #depth
  depth <- environ %>%
    group_by(YEAR) %>%
    summarize(Mean = mean(DEP),
              SD = sd(DEP))
  
  as.data.frame(depth)
  output$DEP <- depth$Mean
  output$DEP.sd <- depth$SD
  
  #######-------#######--------########-------#######--------########
  
  output$Species <-  data$Species[i]
  output.act$Species <-  data$Species[i]
  
  print(output)
  print(output.act)
  
  if(i == 1){
    output.frame <- output
    output.act.frame <- output.act
    
    
  }else{
    output.frame <- rbind(output.frame, output)
    output.act.frame <- rbind(output.act.frame, output.act)
  }
}
